#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MINEXPONENT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MINEXPONENT_HPP_INCLUDED

#include <boost/simd/constant/include/constants/minexponent.hpp>

#endif
